@@ -43,6 +43,7 @@ __all__ = (
     "SigningAlgorithmSpecType",
     "WrappingKeySpecType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -421,3 +422,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_aliases", "list_grants", "list_key_policies", "list_keys"]
