@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -201,7 +201,7 @@ _RequiredCreateGrantRequestRequestTypeDef = TypedDict(
     {
         "KeyId": str,
         "GranteePrincipal": str,
-        "Operations": List[GrantOperationType],
+        "Operations": Sequence[GrantOperationType],
     },
 )
 _OptionalCreateGrantRequestRequestTypeDef = TypedDict(
@@ -209,7 +209,7 @@ _OptionalCreateGrantRequestRequestTypeDef = TypedDict(
     {
         "RetiringPrincipal": str,
         "Constraints": "GrantConstraintsTypeDef",
-        "GrantTokens": List[str],
+        "GrantTokens": Sequence[str],
         "Name": str,
     },
     total=False,
@@ -242,7 +242,7 @@ CreateKeyRequestRequestTypeDef = TypedDict(
         "Origin": OriginTypeType,
         "CustomKeyStoreId": str,
         "BypassPolicyLockoutSafetyCheck": bool,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "MultiRegion": bool,
     },
     total=False,
@@ -279,8 +279,8 @@ _RequiredDecryptRequestRequestTypeDef = TypedDict(
 _OptionalDecryptRequestRequestTypeDef = TypedDict(
     "_OptionalDecryptRequestRequestTypeDef",
     {
-        "EncryptionContext": Dict[str, str],
-        "GrantTokens": List[str],
+        "EncryptionContext": Mapping[str, str],
+        "GrantTokens": Sequence[str],
         "KeyId": str,
         "EncryptionAlgorithm": EncryptionAlgorithmSpecType,
     },
@@ -355,7 +355,7 @@ _RequiredDescribeKeyRequestRequestTypeDef = TypedDict(
 _OptionalDescribeKeyRequestRequestTypeDef = TypedDict(
     "_OptionalDescribeKeyRequestRequestTypeDef",
     {
-        "GrantTokens": List[str],
+        "GrantTokens": Sequence[str],
     },
     total=False,
 )
@@ -420,8 +420,8 @@ _RequiredEncryptRequestRequestTypeDef = TypedDict(
 _OptionalEncryptRequestRequestTypeDef = TypedDict(
     "_OptionalEncryptRequestRequestTypeDef",
     {
-        "EncryptionContext": Dict[str, str],
-        "GrantTokens": List[str],
+        "EncryptionContext": Mapping[str, str],
+        "GrantTokens": Sequence[str],
         "EncryptionAlgorithm": EncryptionAlgorithmSpecType,
     },
     total=False,
@@ -454,8 +454,8 @@ _RequiredGenerateDataKeyPairRequestRequestTypeDef = TypedDict(
 _OptionalGenerateDataKeyPairRequestRequestTypeDef = TypedDict(
     "_OptionalGenerateDataKeyPairRequestRequestTypeDef",
     {
-        "EncryptionContext": Dict[str, str],
-        "GrantTokens": List[str],
+        "EncryptionContext": Mapping[str, str],
+        "GrantTokens": Sequence[str],
     },
     total=False,
 )
@@ -490,8 +490,8 @@ _RequiredGenerateDataKeyPairWithoutPlaintextRequestRequestTypeDef = TypedDict(
 _OptionalGenerateDataKeyPairWithoutPlaintextRequestRequestTypeDef = TypedDict(
     "_OptionalGenerateDataKeyPairWithoutPlaintextRequestRequestTypeDef",
     {
-        "EncryptionContext": Dict[str, str],
-        "GrantTokens": List[str],
+        "EncryptionContext": Mapping[str, str],
+        "GrantTokens": Sequence[str],
     },
     total=False,
 )
@@ -524,10 +524,10 @@ _RequiredGenerateDataKeyRequestRequestTypeDef = TypedDict(
 _OptionalGenerateDataKeyRequestRequestTypeDef = TypedDict(
     "_OptionalGenerateDataKeyRequestRequestTypeDef",
     {
-        "EncryptionContext": Dict[str, str],
+        "EncryptionContext": Mapping[str, str],
         "NumberOfBytes": int,
         "KeySpec": DataKeySpecType,
-        "GrantTokens": List[str],
+        "GrantTokens": Sequence[str],
     },
     total=False,
 )
@@ -558,10 +558,10 @@ _RequiredGenerateDataKeyWithoutPlaintextRequestRequestTypeDef = TypedDict(
 _OptionalGenerateDataKeyWithoutPlaintextRequestRequestTypeDef = TypedDict(
     "_OptionalGenerateDataKeyWithoutPlaintextRequestRequestTypeDef",
     {
-        "EncryptionContext": Dict[str, str],
+        "EncryptionContext": Mapping[str, str],
         "KeySpec": DataKeySpecType,
         "NumberOfBytes": int,
-        "GrantTokens": List[str],
+        "GrantTokens": Sequence[str],
     },
     total=False,
 )
@@ -660,7 +660,7 @@ _RequiredGetPublicKeyRequestRequestTypeDef = TypedDict(
 _OptionalGetPublicKeyRequestRequestTypeDef = TypedDict(
     "_OptionalGetPublicKeyRequestRequestTypeDef",
     {
-        "GrantTokens": List[str],
+        "GrantTokens": Sequence[str],
     },
     total=False,
 )
@@ -689,8 +689,8 @@ GetPublicKeyResponseTypeDef = TypedDict(
 GrantConstraintsTypeDef = TypedDict(
     "GrantConstraintsTypeDef",
     {
-        "EncryptionContextSubset": Dict[str, str],
-        "EncryptionContextEquals": Dict[str, str],
+        "EncryptionContextSubset": Mapping[str, str],
+        "EncryptionContextEquals": Mapping[str, str],
     },
     total=False,
 )
@@ -1005,12 +1005,12 @@ _RequiredReEncryptRequestRequestTypeDef = TypedDict(
 _OptionalReEncryptRequestRequestTypeDef = TypedDict(
     "_OptionalReEncryptRequestRequestTypeDef",
     {
-        "SourceEncryptionContext": Dict[str, str],
+        "SourceEncryptionContext": Mapping[str, str],
         "SourceKeyId": str,
-        "DestinationEncryptionContext": Dict[str, str],
+        "DestinationEncryptionContext": Mapping[str, str],
         "SourceEncryptionAlgorithm": EncryptionAlgorithmSpecType,
         "DestinationEncryptionAlgorithm": EncryptionAlgorithmSpecType,
-        "GrantTokens": List[str],
+        "GrantTokens": Sequence[str],
     },
     total=False,
 )
@@ -1047,7 +1047,7 @@ _OptionalReplicateKeyRequestRequestTypeDef = TypedDict(
         "Policy": str,
         "BypassPolicyLockoutSafetyCheck": bool,
         "Description": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1143,7 +1143,7 @@ _OptionalSignRequestRequestTypeDef = TypedDict(
     "_OptionalSignRequestRequestTypeDef",
     {
         "MessageType": MessageTypeType,
-        "GrantTokens": List[str],
+        "GrantTokens": Sequence[str],
     },
     total=False,
 )
@@ -1169,7 +1169,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "KeyId": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1185,7 +1185,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "KeyId": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1250,7 +1250,7 @@ _OptionalVerifyRequestRequestTypeDef = TypedDict(
     "_OptionalVerifyRequestRequestTypeDef",
     {
         "MessageType": MessageTypeType,
-        "GrantTokens": List[str],
+        "GrantTokens": Sequence[str],
     },
     total=False,
 )
